searchData={"items":[{"type":"module","title":"Circuits.SPI","doc":"This module enables Elixir programs to interact with hardware that's connected\nvia a SPI bus.","ref":"Circuits.SPI.html"},{"type":"function","title":"Circuits.SPI.bus_names/0","doc":"Return a list of available SPI bus names.  If nothing is returned,\nit's possible that the kernel driver for that SPI bus is not enabled or the\nkernel's device tree is not configured. On Raspbian, run `raspi-config` and\nlook in the advanced options.\n```\niex> Circuits.SPI.bus_names\n[\"spidev0.0\", \"spidev0.1\"]\n```","ref":"Circuits.SPI.html#bus_names/0"},{"type":"function","title":"Circuits.SPI.close/1","doc":"Release any resources associated with the given file descriptor","ref":"Circuits.SPI.html#close/1"},{"type":"function","title":"Circuits.SPI.config/1","doc":"Return the configuration for this SPI bus\n\nThe configuration could be different that what was given to `open/2` if\nthe device had to change it for it to work.","ref":"Circuits.SPI.html#config/1"},{"type":"function","title":"Circuits.SPI.info/1","doc":"Return info about the low level SPI interface\n\nThis may be helpful when debugging SPI issues.","ref":"Circuits.SPI.html#info/1"},{"type":"function","title":"Circuits.SPI.max_transfer_size/1","doc":"Return the maximum transfer size in bytes\n\nThe number of bytes that can be sent and received at a time\nmay be capped by the low level SPI interface. For example,\nthe Linux `spidev` driver allocates its transfer buffer at\ninitialization based on the `bufsiz` parameter and rejects\nrequests that won't fit.\n\nIf you're sending large amounts of data over SPI, use this\nfunction to determine how to split up large messages.","ref":"Circuits.SPI.html#max_transfer_size/1"},{"type":"function","title":"Circuits.SPI.open/2","doc":"Open a SPI bus device\n\nOn success, `open/2` returns a reference that may be passed to\nwith `transfer/2`. The device will be closed automatically when\nthe reference goes out of scope.\n\nSPI is not a standardized interface so appropriate options will\ndifferent from device-to-device. The defaults use here work on\nmany devices.\n\nParameters:\n* `bus_name` is the name of the bus (e.g., \"spidev0.0\"). See `bus_names/0`\n* `opts` is a keyword list to configure the bus","ref":"Circuits.SPI.html#open/2"},{"type":"function","title":"Circuits.SPI.transfer/2","doc":"Transfer data\n\nSince each SPI transfer sends and receives simultaneously, the return value\nwill be a binary of the same length as `data`.","ref":"Circuits.SPI.html#transfer/2"},{"type":"function","title":"Circuits.SPI.transfer!/2","doc":"Transfer data and raise on error","ref":"Circuits.SPI.html#transfer!/2"},{"type":"type","title":"Circuits.SPI.backend/0","doc":"Backends specify an implementation of a Circuits.SPI.Backend behaviour\n\nThe second parameter of the Backend 2-tuple is a list of options. These are\npassed to the behaviour function call implementations.","ref":"Circuits.SPI.html#t:backend/0"},{"type":"type","title":"Circuits.SPI.spi_option/0","doc":"SPI bus options\n\nOptions:\n\n* `mode` - Set the clock polarity and phase to use:\n  * Mode 0 (CPOL=0, CPHA=0) - Clock idle low/sample leading edge (default)\n  * Mode 1 (CPOL=0, CPHA=1) - Clock idle low/sample trailing edge\n  * Mode 2 (CPOL=1, CPHA=0) - Clock idle high/sample leading edge\n  * Mode 3 (CPOL=1, CPHA=1) - Clock idle high/sample trailing edge\n* `bits_per_word` - Set the bits per word on the bus. Defaults to 8 bit words.\n* `speed_hz` - Set the bus speed. Supported speeds are device-specific. The\n  default speed is 1 Mbps (1000000).\n* `delay_us` - Set the delay between transactions (10)\n* `lsb_first` - Set to `true` to send the least significant bit first rather\n  than the most significant one. (false)","ref":"Circuits.SPI.html#t:spi_option/0"},{"type":"type","title":"Circuits.SPI.spi_option_map/0","doc":"SPI bus options as returned by `config/1`.\n\nThese mirror the options that can be passed to `open/2`. `:sw_lsb_first`\nis set if `:lsb_first` is true, but Circuits.SPI is doing this in software.","ref":"Circuits.SPI.html#t:spi_option_map/0"},{"type":"behaviour","title":"Circuits.SPI.Backend","doc":"Backends provide the connection to the real or virtual SPI controller","ref":"Circuits.SPI.Backend.html"},{"type":"callback","title":"Circuits.SPI.Backend.bus_names/1","doc":"Return SPI bus names on this system\n\nNo supported options","ref":"Circuits.SPI.Backend.html#c:bus_names/1"},{"type":"callback","title":"Circuits.SPI.Backend.info/0","doc":"Return information about this backend","ref":"Circuits.SPI.Backend.html#c:info/0"},{"type":"callback","title":"Circuits.SPI.Backend.open/2","doc":"Open a SPI bus device\n\nOn success, `open/2` returns a reference that may be passed to\nwith `transfer/2`. The device will be closed automatically when\nthe reference goes out of scope.\n\nSPI is not a standardized interface so appropriate options will\ndifferent from device-to-device. The defaults use here work on\nmany devices.\n\nParameters:\n* `bus_name` is the name of the bus (e.g., \"spidev0.0\"). See `bus_names/0`\n* `opts` is a keyword list to configure the bus","ref":"Circuits.SPI.Backend.html#c:open/2"},{"type":"protocol","title":"Circuits.SPI.Bus","doc":"A bus is the connection to a real or virtual SPI controller","ref":"Circuits.SPI.Bus.html"},{"type":"function","title":"Circuits.SPI.Bus.close/1","doc":"Free up resources associated with the bus\n\nWell behaved backends free up their resources with the help of the Erlang garbage collector. However, it is good\npractice for users to call `Circuits.SPI.close/1` (and hence this function) so that\nlimited resources are freed before they're needed again.","ref":"Circuits.SPI.Bus.html#close/1"},{"type":"function","title":"Circuits.SPI.Bus.config/1","doc":"Return the configuration for this SPI bus\n\nThe configuration could be different that what was given to `open/2` if\nthe device had to change it for it to work.","ref":"Circuits.SPI.Bus.html#config/1"},{"type":"function","title":"Circuits.SPI.Bus.max_transfer_size/1","doc":"Return the maximum transfer size in bytes\n\nThe number of bytes that can be sent and received at a time\nmay be capped by the low level SPI interface. For example,\nthe Linux `spidev` driver allocates its transfer buffer at\ninitialization based on the `bufsiz` parameter and rejects\nrequests that won't fit.\n\nIf you're sending large amounts of data over SPI, use this\nfunction to determine how to split up large messages.","ref":"Circuits.SPI.Bus.html#max_transfer_size/1"},{"type":"function","title":"Circuits.SPI.Bus.transfer/2","doc":"Transfer data\n\nSince each SPI transfer sends and receives simultaneously, the return value\nwill be a binary of the same length as `data`.","ref":"Circuits.SPI.Bus.html#transfer/2"},{"type":"type","title":"Circuits.SPI.Bus.t/0","doc":"All the types that implement this protocol.","ref":"Circuits.SPI.Bus.html#t:t/0"},{"type":"module","title":"Circuits.SPI.NilBackend","doc":"Circuits.SPI backend when nothing else is available","ref":"Circuits.SPI.NilBackend.html"},{"type":"function","title":"Circuits.SPI.NilBackend.bus_names/1","doc":"Return the SPI bus names on this system\n\nNo supported options","ref":"Circuits.SPI.NilBackend.html#bus_names/1"},{"type":"function","title":"Circuits.SPI.NilBackend.info/0","doc":"Return information about this backend","ref":"Circuits.SPI.NilBackend.html#info/0"},{"type":"function","title":"Circuits.SPI.NilBackend.open/2","doc":"Open an I2C bus\n\nNo supported options.","ref":"Circuits.SPI.NilBackend.html#open/2"},{"type":"module","title":"Circuits.SPI.SPIDev","doc":"Circuits.SPI backend for the Linux spidev interface\n\nThis backend works on Nerves, embedded Linux, and desktop Linux.","ref":"Circuits.SPI.SPIDev.html"},{"type":"function","title":"Circuits.SPI.SPIDev.bus_names/1","doc":"Return the SPI bus names on this system\n\nNo supported options","ref":"Circuits.SPI.SPIDev.html#bus_names/1"},{"type":"function","title":"Circuits.SPI.SPIDev.info/0","doc":"Return information about this backend","ref":"Circuits.SPI.SPIDev.html#info/0"},{"type":"function","title":"Circuits.SPI.SPIDev.open/2","doc":"Open an SPI bus","ref":"Circuits.SPI.SPIDev.html#open/2"},{"type":"extras","title":"Circuits.SPI","doc":"# Circuits.SPI\n\n[![Hex version](https://img.shields.io/hexpm/v/circuits_spi.svg \"Hex version\")](https://hex.pm/packages/circuits_spi)\n[![API docs](https://img.shields.io/hexpm/v/circuits_spi.svg?label=hexdocs \"API docs\")](https://hexdocs.pm/circuits_spi/Circuits.SPI.html)\n[![CircleCI](https://circleci.com/gh/elixir-circuits/circuits_spi.svg?style=svg)](https://circleci.com/gh/elixir-circuits/circuits_spi)\n[![REUSE status](https://api.reuse.software/badge/github.com/elixir-circuits/circuits_spi)](https://api.reuse.software/info/github.com/elixir-circuits/circuits_spi)\n\n`Circuits.SPI` lets you communicate with hardware devices using the SPI protocol.\n\n*This is Circuits.SPI v2. Circuits.SPI v1.x is still maintained in the [maint-v1.x branch](https://github.com/elixir-circuits/circuits_spi/tree/maint-v1.x).*\n\n`Circuits.SPI` v2.0  is an almost backwards compatible update to `Circuits.SPI`\nv1.x. Here's what's new:\n\n* Linux or Nerves are no longer required. In fact, the NIF supporting them won't\n  be compiled if you don't want it.\n* Develop using simulated SPI devices with\n  [CircuitsSim](https://github.com/elixir-circuits/circuits_sim)\n* Use USB->SPI adapters for development on your laptop (Coming soon)\n\nIf you've used `Circuits.SPI` v1.x, nearly all of your code will be the same. If\nyou're a library author, we'd appreciate if you could try this out and update\nyour `:circuits_spi` dependency to allow v2.0. Details can be found in our\n[porting guide](PORTING.md).","ref":"readme.html"},{"type":"extras","title":"Getting started on Nerves and Linux - Circuits.SPI","doc":"If you're using Nerves or compiling on a Raspberry Pi or other device with SPI\nsupport, then add `circuits_spi` like any other Elixir library:\n\n```elixir\ndef deps do\n  [{:circuits_spi, \"~> 2.0\"}]\nend\n```\n\n`Circuits.SPI` doesn't load device drivers, so you'll need to load any necessary\nones beforehand. On the Raspberry Pi, the [Adafruit Raspberry Pi SPI\ninstructions](https://learn.adafruit.com/adafruits-raspberry-pi-lesson-4-gpio-setup/configuring-spi)\nmay be helpful, (This is already enabled for you if you are using Nerves)\n\n\nA [Serial Peripheral\nInterface](https://en.wikipedia.org/wiki/Serial_Peripheral_Interface_Bus) (SPI)\nbus is a common multi-wire bus used to connect components on a circuit board. A\nclock line drives the timing of sending bits between components. Bits on the\nController Out Peripheral In `COPI` line go from the controller (usually the processor\nrunning Linux) to the peripheral, and bits on the Controller In Peripheral Out `CIPO` line go\nthe other direction. Bits transfer both directions simultaneously. However, much\nof the time, the protocol used across the SPI bus has a request followed by a\nresponse and in these cases, bits going the \"wrong\" direction are ignored. This\nwill become more clear in the example below.\n\nThe following shows an example Analog to Digital Converter (ADC) that reads from\neither a temperature sensor on CH0 (channel 0) or a potentiometer on CH1\n(channel 1). It converts the analog measurements to digital, and sends the\ndigital measurements to SPI pins on the main processor running Linux (e.g.\nRaspberry Pi). Many processors, like the one on the Raspberry Pi, can't read\nanalog signals directly, so they need an ADC to convert the signal.\n\n![SPI schematic](assets/images/schematic-adc.png)\n\nThe protocol for talking to the ADC in the example below is described in the\n[MCP3002](http://www.microchip.com/wwwproducts/en/MCP3002) data sheet. The\nprotocol is very similar to an application program interface (API) for\nsoftware. It will tell you the position and function of the bits you will send\nto the ADC, along with how the data (in the form of bits)\nwill be returned.\n\nSee Figure 6-1 in the data sheet for the communication protocol. Sending a\n`0x68` first reads the temperature and sending a `0x78` reads the\npotentiometer. Since the data sheet shows bits, `0x68` corresponds to `01101000b`.\nThe leftmost bit is the \"Start\" bit. The second bit is SGL/DIFF, the third\nbit is ODD/SIGN, and the fourth bit is MSBF. From table 5-1, if SGL/DIFF==1,\nODD/SIGN==0, and MSBF==1 then that specifies channel 0 which is connected to\nthe thermometer.\n\n```elixir\n# Make sure that you've enabled or loaded the SPI driver or this will\n# fail.\niex> {:ok, ref} = Circuits.SPI.open(\"spidev0.0\")\n{:ok, #Reference<...>}\n\n# Read the potentiometer\n\n# Use binary pattern matching to pull out the ADC counts (low 10 bits)\niex> {:ok, <<_::size(6), counts::size(10)>>} = Circuits.SPI.transfer(ref, <<0x78, 0x00>>)\n{:ok, <<1, 197>>}\n\niex> counts\n453\n\n# Convert counts to volts (1023 = 3.3 V)\niex> volts = counts / 1023 * 3.3\n1.461290322580645\n```\n\nAs shown above, you'll find out that Elixir's binary pattern matching is\nextremely convenient when working with hardware. More information can be\nfound in the [Kernel.SpecialForms documentation](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#%3C%3C%3E%3E/1)\nand by running `h <<>>` at the IEx prompt.","ref":"readme.html#getting-started-on-nerves-and-linux"},{"type":"extras","title":"FAQ - Circuits.SPI","doc":"#","ref":"readme.html#faq"},{"type":"extras","title":"How do I only receive data? - Circuits.SPI","doc":"SPI always sends a bit for every bit it receives. That means that to receive a\nbyte, you have to send a byte. Luckily, devices are designed with this in mind\nand discard or ignore bytes in these situations. For example, if you have a\nsensors and need to read 9 bytes of data, send 9 zeros to read it. The zeros\nwill be ignored and you'll get the data.\n\n#","ref":"readme.html#how-do-i-only-receive-data"},{"type":"extras","title":"How do I debug? - Circuits.SPI","doc":"The most common issue is communicating with a SPI device for the first time.\nFirst check that a SPI bus is available:\n\n```elixir\niex> Circuits.SPI.bus_names()\n[\"spidev0.0\", \"spidev0.1\"]\n```\n\nIf the list is empty, then a SPI bus is either not available, not enabled, or\nnot configured in the kernel. If you're using Raspbian, run `raspi-config` and\ncheck that SPI is enabled in the advanced options. If you're on a BeagleBone,\ntry running `config-pin` and see the [Universal I/O\nproject](https://github.com/cdsteinkuehler/beaglebone-universal-io) to enable\nthe SPI pins. On other ARM boards, double check that SPI is enabled in the\nkernel and that the device tree configures it.\n\n#","ref":"readme.html#how-do-i-debug"},{"type":"extras","title":"How do I set the speed of the SPI bus? - Circuits.SPI","doc":"SPI bus options like frequency (`:speed_hz`) and bits per word (`:bit_per_word`)\nare set as optional parameters to\n[`Circuits.SPI.open/2`](https://hexdocs.pm/circuits_spi/Circuits.SPI.html#open/2).\n\nFor example, the following configures the SPI bus to run at 122,000 Hz:\n\n```elixir\n{:ok, my_spi} = Circuits.SPI.open(\"spidev0.0\", speed_hz: 122000)`\n```\n\nThe ability to set the bus speed is device-specific. Please verify with a logic\nanalyzer that the speed is actually being set and consult the documentation for\nlimitations.\n\n#","ref":"readme.html#how-do-i-set-the-speed-of-the-spi-bus"},{"type":"extras","title":"Where can I get help? - Circuits.SPI","doc":"Many issues are unrelated to `Circuits.SPI`. If you expand your searches to\ninclude Python and C forums, it's possible that someone else has run into your\nproblem too. SPI libraries in other languages should be similar to\n`Circuits.SPI` so hopefully you'll find the answer.\n\nIf that fails, try posting a question to the [Elixir\nForum](https://elixirforum.com/). Tag the question with `Nerves` and it will\nhave a good chance of getting to the right people. Feel free to do this even if\nyou're not using Nerves.\n\n#","ref":"readme.html#where-can-i-get-help"},{"type":"extras","title":"Can I develop code that uses Circuits.SPI on my laptop? - Circuits.SPI","doc":"You have a few options:\n\n1. Use the CircuitsSim backend\n2. Create a custom backend and use it to mock interactions with the Circuits.SPI\n   API\n\nWe hope to have support for USB adapters that have SPI interfaces in the future.","ref":"readme.html#can-i-develop-code-that-uses-circuits-spi-on-my-laptop"},{"type":"extras","title":"License - Circuits.SPI","doc":"All original source code in this project is licensed under Apache-2.0.\n\nAdditionally, this project follows the [REUSE recommendations](https://reuse.software)\nand labels so that licensing and copyright are clear at the file level.\n\nExceptions to Apache-2.0 licensing are:\n\n* Configuration and data files are licensed under CC0-1.0\n* Documentation files are CC-BY-4.0\n* Erlang Embedded board images are Solderpad Hardware License v0.51.","ref":"readme.html#license"},{"type":"extras","title":"Porting","doc":"# Porting","ref":"porting.html"},{"type":"extras","title":"Upgrading Circuits.SPI 1.x projects to 2.0 - Porting","doc":"Circuits.SPI 2.0 supports alternative SPI hardware and the ability to mock or\nemulate devices via backends. The Linux spi-dev backend is the default and this\nmatches Circuits.SPI 1.x. Most projects won't need any changes other than to\nupdate the dependency in `mix.exs`. If upgrading a library, The following\ndependency specification is recommended to allow both `circuits_i2c` versions:\n\n```elixir\n   {:circuits_spi, \"~> 2.0 or ~> 1.0\"}\n```\n\nThe following potentially breaking changes were made:\n\n1. `Circuits.SPI.open/1` no longer accepts Erlang strings.\n2. The `stub` implementation has been renamed to `spi_dev_test`. If using the\n   stub implementation for testing, you may have to update your tests since\n   there were minor changes.","ref":"porting.html#upgrading-circuits-spi-1-x-projects-to-2-0"},{"type":"extras","title":"Upgrading Elixir/ALE projects to Circuits.SPI - Porting","doc":"The `Circuits.SPI` package is the next version of Elixir/ALE's SPI support.\nIf you're currently using Elixir/ALE, you're encouraged to switch. Here are some\nbenefits:\n\n1. Supported by both the maintainer of Elixir/ALE and a couple others. They'd\n   prefer to support `Circuits.SPI` issues.\n2. Much faster than Elixir/ALE.\n3. Simplified API\n\n`Circuits.SPI` uses Erlang's NIF interface. NIFs have the downside of being able\nto crash the Erlang VM. Experience with Elixir/ALE has given many of us\nconfidence that this won't be a problem.\n\n#","ref":"porting.html#upgrading-elixir-ale-projects-to-circuits-spi"},{"type":"extras","title":"Code modifications - Porting","doc":"`Circuits.SPI` is not a `GenServer`, so if you've added `ElixirALE.SPI` to a\nsupervision tree, you'll have to take it out and manually call\n`Circuits.SPI.open` to obtain a reference. A common pattern is to create a\n`GenServer` that is descriptive of what the SPI device does and have it be\nresponsible for all SPI calls.\n\nThe remain modifications should mostly be mechanical:\n\n1. Rename references to `ElixirALE.SPI` to `Circuits.SPI` and `elixir_ale`\n   to `circuits_spi`\n2. Change calls to `ElixirALE.SPI.start_link/2` to `Circuits.SPI.open/1`.\n   Review the arguments to open to not include any `GenServer` options.\n3. The `transfer` function now returns `{:ok, result}` tuples on\n   success so add code to handle that.\n4. Consider adding a call to `Circuits.SPI.close/1` if there's an obvious place\n   to release the SPI bus. This is not strictly necessary since the garbage\n   collector will free unreferenced SPI references.\n5. Change calls to `ElixirALE.SPI.device_names/0` to `Circuits.SPI.bus_names/0`.\n\nIf you find that you have to make any other changes, please let us know via an\nissue or PR so that other users can benefit.","ref":"porting.html#code-modifications"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v2.0.1 - 2024-01-14 - Changelog","doc":"* Changes\n  * Fix race condition when multiple processes load the NIF simultaneously that\n    would cause an unnecessary crash.","ref":"changelog.html#v2-0-1-2024-01-14"},{"type":"extras","title":"v2.0.0 - 2023-11-12 - Changelog","doc":"Official v2.0.0 release. No changes from v2.0.0-pre.0.","ref":"changelog.html#v2-0-0-2023-11-12"},{"type":"extras","title":"v2.0.0-pre.0 - 2023-05-30 - Changelog","doc":"This is a major update to Circuits.SPI that removes the requirement to use\nNerves or Linux. The API is almost the same and the default is to compile and\nuse the Linux backend, so changes may not be needed.\n\nThis is a prerelease so APIs may still change before the v2.0.0 release.\n\n* Changes\n  * Support alternative backends for different operating systems or for\n    simulated hardware\n  * Defer loading the Linux NIF until `Circuits.SPI.open/2` is called","ref":"changelog.html#v2-0-0-pre-0-2023-05-30"},{"type":"extras","title":"v1.4.0 - 2022-12-31 - Changelog","doc":"* Changes\n  * Remove Erlang convenience functions since no one used them\n  * Require Elixir 1.10 or later. Previous versions probably work, but won't be\n    supported. This opens up the possibility of using Elixir 1.10+ features in\n    future releases.","ref":"changelog.html#v1-4-0-2022-12-31"},{"type":"extras","title":"v1.3.0 - 2022-02-21 - Changelog","doc":"* Updates\n  * Add `transfer!/2`. This function is the raising version of `transfer/2`.\n    Thanks to @mnishiguchi for this.","ref":"changelog.html#v1-3-0-2022-02-21"},{"type":"extras","title":"v1.2.0 - 2022-01-23 - Changelog","doc":"* Updates\n  * Add the `:lsb_first` option to support SPI transfers that send the least\n    significant bit first rather than the most significant one. If the bit\n    reversal isn't supported by the hardware, a software version is used.\n  * Add `config/1` to return the configuration for an SPI bus reference. This is\n    useful for checking what is actually being used.\n  * Update `transfer/2` to support `iodata`. This makes the interface more\n    convenient since now you can prepend SPI message headers in your code\n    without having to concatenate binaries.\n  * Support full pathes being passed to SPI devices in `open/2`. Previously this\n    resulted in errors, but it was easy to forget.","ref":"changelog.html#v1-2-0-2022-01-23"},{"type":"extras","title":"v1.1.0 - 2021-12-28 - Changelog","doc":"* Updates\n  * Add `max_transfer_size/0` to return the low level maximum size that can be\n    sent at a time. Thanks to @cocoa-xu for this.\n\n* Bug fixes\n  * Properly mark NIF transfer function as IO bound so that the Erlang scheduler\n    schedules it properly.","ref":"changelog.html#v1-1-0-2021-12-28"},{"type":"extras","title":"v1.0.0 - 2021-10-20 - Changelog","doc":"This release only changes the version number. No code has changed.","ref":"changelog.html#v1-0-0-2021-10-20"},{"type":"extras","title":"v0.1.6 - Changelog","doc":"This release only has doc and build output cleanup. No code has changed.","ref":"changelog.html#v0-1-6"},{"type":"extras","title":"v0.1.5 - Changelog","doc":"* Bug fixes\n  * Add -fPIC to compilation flags to fix build with `nerves_system_x86_64` and\n    other environments using the Musl C toolchains","ref":"changelog.html#v0-1-5"},{"type":"extras","title":"v0.1.4 - Changelog","doc":"This release doesn't functionally change any code. The only updates are to build\nfiles for consistency with other Circuits projects.","ref":"changelog.html#v0-1-4"},{"type":"extras","title":"v0.1.3 - Changelog","doc":"* Bug fixes\n  * Fix binary handling in NIF. This fixes segfaults and other errors on\n    Raspbian.","ref":"changelog.html#v0-1-3"},{"type":"extras","title":"v0.1.2 - Changelog","doc":"* Bug fixes\n  * Fix file handle leak when SPI bus references were garbage collected.","ref":"changelog.html#v0-1-2"},{"type":"extras","title":"v0.1.1 - Changelog","doc":"* Bug fixes\n  * Build C source under the `_build` directory so that changing targets\n    properly rebuilds the C code as well as the Elixir code.","ref":"changelog.html#v0-1-1"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"Initial release to hex.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}